@@ -129,14 +129,12 @@ gl_xml_template_parse_templates_doc (const xmlDocPtr templates_doc)
 	root = xmlDocGetRootElement (templates_doc);
 	if (!root || !root->name) {
 		g_warning ("\"%s\" is not a glabels template file (no root node)",
-			   templates_doc->name);
-		xmlFreeDoc (templates_doc);
+			   templates_doc->URL);
 		return templates;
 	}
 	if (!xmlStrEqual (root->name, "Glabels-templates")) {
 		g_warning ("\"%s\" is not a glabels template file (wrong root node)",
-		      templates_doc->name);
-		xmlFreeDoc (templates_doc);
+		      templates_doc->URL);
 		return templates;
 	}
 
@@ -175,7 +173,14 @@ gl_xml_template_parse_template_node (const xmlNodePtr template_node)
 
 	description = xmlGetProp (template_node, "_description");
 	if (description != NULL) {
-		description = gettext (description);
+
+		gchar *tmp = gettext (description);
+
+		if (tmp != description) {
+			g_free (description);
+			description = g_strdup (tmp);
+		}
+
 	} else {
 		description = xmlGetProp (template_node, "description");
 	}
@@ -243,18 +248,28 @@ xml_parse_label_rectangle_node (xmlNodePtr  label_node,
 				glTemplate *template)
 {
 	gchar               *id;
-	gdouble              waste;
+	gchar               *tmp;
+	gdouble              x_waste, y_waste;
 	gdouble              w, h, r;
 	glTemplateLabelType *label_type;
 	xmlNodePtr           node;
 
-	id    = xmlGetProp (label_node, "id");
-	waste = gl_xml_get_prop_length (label_node, "waste", 0);
-	w     = gl_xml_get_prop_length (label_node, "width", 0);
-	h     = gl_xml_get_prop_length (label_node, "height", 0);
-	r     = gl_xml_get_prop_length (label_node, "round", 0);
+	id      = xmlGetProp (label_node, "id");
 
-	label_type = gl_template_rect_label_type_new (id, w, h, r, waste);
+	if (tmp = xmlGetProp (label_node, "waste")) {
+		/* Handle single "waste" property. */
+		x_waste = y_waste = gl_xml_get_prop_length (label_node, "waste", 0);
+		g_free (tmp);
+	} else {
+		x_waste = gl_xml_get_prop_length (label_node, "x_waste", 0);
+		y_waste = gl_xml_get_prop_length (label_node, "y_waste", 0);
+	}
+
+	w       = gl_xml_get_prop_length (label_node, "width", 0);
+	h       = gl_xml_get_prop_length (label_node, "height", 0);
+	r       = gl_xml_get_prop_length (label_node, "round", 0);
+
+	label_type = gl_template_rect_label_type_new (id, w, h, r, x_waste, y_waste);
 	gl_template_add_label_type (template, label_type);
 
 	for (node = label_node->xmlChildrenNode; node != NULL;
@@ -608,14 +623,15 @@ xml_create_label_node (const glTemplateLabelType  *label_type,
 		gl_xml_set_prop_length (node, "width",  label_type->size.rect.w);
 		gl_xml_set_prop_length (node, "height", label_type->size.rect.h);
 		gl_xml_set_prop_length (node, "round",  label_type->size.rect.r);
-		gl_xml_set_prop_length (node, "waste",  label_type->waste);
+		gl_xml_set_prop_length (node, "x_waste",  label_type->size.rect.x_waste);
+		gl_xml_set_prop_length (node, "y_waste",  label_type->size.rect.y_waste);
 		break;
 
 	case GL_TEMPLATE_SHAPE_ROUND:
 		node = xmlNewChild(root, ns, "Label-round", NULL);
 		xmlSetProp (node, "id", label_type->id);
 		gl_xml_set_prop_length (node, "radius",  label_type->size.round.r);
-		gl_xml_set_prop_length (node, "waste",   label_type->waste);
+		gl_xml_set_prop_length (node, "waste",   label_type->size.round.waste);
 		break;
 
 	case GL_TEMPLATE_SHAPE_CD:
@@ -629,7 +645,7 @@ xml_create_label_node (const glTemplateLabelType  *label_type,
 		if (label_type->size.cd.h != 0.0) {
 			gl_xml_set_prop_length (node, "height", label_type->size.cd.h);
 		}
-		gl_xml_set_prop_length (node, "waste",  label_type->waste);
+		gl_xml_set_prop_length (node, "waste",  label_type->size.cd.waste);
 		break;
 
 	default:
@@ -639,11 +655,6 @@ xml_create_label_node (const glTemplateLabelType  *label_type,
 
 	}
 
-	for ( p=label_type->layouts; p != NULL; p=p->next ) {
-		layout = (glTemplateLayout *)p->data;
-		xml_create_layout_node (layout, node, ns);
-	}
-
 	for ( p=label_type->markups; p != NULL; p=p->next ) {
 		markup = (glTemplateMarkup *)p->data;
 		switch (markup->type) {
@@ -662,6 +673,11 @@ xml_create_label_node (const glTemplateLabelType  *label_type,
 		}
 	}
 
+	for ( p=label_type->layouts; p != NULL; p=p->next ) {
+		layout = (glTemplateLayout *)p->data;
+		xml_create_layout_node (layout, node, ns);
+	}
+
 }
 
 /*--------------------------------------------------------------------------*/
