@@ -521,7 +521,7 @@ print_crop_marks (PrintInfo *pi)
 	page_w = pi->page_width;
 	page_h = pi->page_height;
 
-	gnome_print_setrgbcolor (pi->pc, 0.25, 0.25, 0.25);
+	gnome_print_setrgbcolor (pi->pc, 0.0, 0.0, 0.0);
 	gnome_print_setopacity (pi->pc, 1.0);
 	gnome_print_setlinewidth (pi->pc, 0.25);
 
@@ -721,22 +721,23 @@ draw_text_object (PrintInfo     *pi,
 		  glLabelText   *object,
 		  glMergeRecord *record)
 {
-	GnomeFont *font;
-	gchar **line;
-	gint i;
-	gdouble x_offset, y_offset, w, object_w, object_h;
-	gchar *text;
-	GList *lines;
-	gchar *font_family;
-	gdouble font_size;
-	GnomeFontWeight font_weight;
-	gboolean font_italic_flag;
-	guint color;
+	GnomeFont       *font;
+	gchar          **line;
+	gint             i;
+	gdouble          x_offset, y_offset, w, object_w, object_h;
+	gchar           *text;
+	GList           *lines;
+	gchar           *font_family;
+	gdouble          font_size;
+	GnomeFontWeight  font_weight;
+	gboolean         font_italic_flag;
+	guint            color;
 	GtkJustification just;
-	GnomeGlyphList *glyphlist;
-	ArtDRect bbox;
-	gdouble affine[6];
-	gdouble text_line_spacing;
+	gboolean         auto_shrink;
+	GnomeGlyphList  *glyphlist;
+	ArtDRect         bbox;
+	gdouble          affine[6];
+	gdouble          text_line_spacing;
 
 
 	gl_debug (DEBUG_PRINT, "START");
@@ -749,7 +750,55 @@ draw_text_object (PrintInfo     *pi,
 	font_italic_flag = gl_label_object_get_font_italic_flag (GL_LABEL_OBJECT(object));
 	color = gl_label_object_get_text_color (GL_LABEL_OBJECT(object));
 	just = gl_label_object_get_text_alignment (GL_LABEL_OBJECT(object));
-	text_line_spacing = gl_label_object_get_text_line_spacing (GL_LABEL_OBJECT(object));
+	text_line_spacing =
+		gl_label_object_get_text_line_spacing (GL_LABEL_OBJECT(object));
+	auto_shrink = gl_label_text_get_auto_shrink (object);
+
+	text = gl_text_node_lines_expand (lines, record);
+	line = g_strsplit (text, "\n", -1);
+	g_free (text);
+
+	art_affine_identity (affine);
+
+	if (record && auto_shrink) {
+		/* auto shrink text size to keep within text box limits. */
+		for (i = 0; line[i] != NULL; i++) {
+
+			font = gnome_font_find_closest_from_weight_slant (font_family,
+									  font_weight,
+									  font_italic_flag,
+									  font_size);
+			glyphlist = gnome_glyphlist_from_text_dumb (font,
+								    color,
+								    0.0, 0.0,
+								    line[i]);
+			gnome_glyphlist_bbox (glyphlist, affine, 0, &bbox);
+			w = bbox.x1;
+			gnome_glyphlist_unref (glyphlist);
+
+			/* If width is too large, iteratively shrink font_size until this
+			   line fits the width, or until the font size is ridiculously
+			   small. */
+			while ( (w > object_w) && (font_size >= 1.0) ) {
+
+				font_size -= 0.5;
+
+				font = gnome_font_find_closest_from_weight_slant (
+					font_family,
+					font_weight,
+					font_italic_flag,
+					font_size);
+				glyphlist = gnome_glyphlist_from_text_dumb (font,
+									    color,
+									    0.0, 0.0,
+									    line[i]);
+				gnome_glyphlist_bbox (glyphlist, affine, 0, &bbox);
+				w = bbox.x1;
+				gnome_glyphlist_unref (glyphlist);
+			}
+		}
+
+	}
 
 	font = gnome_font_find_closest_from_weight_slant (
                                        font_family,
@@ -764,12 +813,6 @@ draw_text_object (PrintInfo     *pi,
 				 GL_COLOR_F_BLUE (color));
 	gnome_print_setopacity (pi->pc, GL_COLOR_F_ALPHA (color));
 
-	text = gl_text_node_lines_expand (lines, record);
-	line = g_strsplit (text, "\n", -1);
-	g_free (text);
-
-	art_affine_identity (affine);
-
 	for (i = 0; line[i] != NULL; i++) {
 
 		glyphlist = gnome_glyphlist_from_text_dumb (font, color,
@@ -778,6 +821,7 @@ draw_text_object (PrintInfo     *pi,
 
 		gnome_glyphlist_bbox (glyphlist, affine, 0, &bbox);
 		w = bbox.x1;
+		gnome_glyphlist_unref (glyphlist);
 
 		switch (just) {
 		case GTK_JUSTIFY_LEFT:
@@ -1004,13 +1048,14 @@ draw_barcode_object (PrintInfo      *pi,
 	gboolean            text_flag;
 	gboolean            checksum_flag;
 	guint               color;
+	guint               format_digits;
 	gdouble             w, h;
 
 	gl_debug (DEBUG_PRINT, "START");
 
 	text_node = gl_label_barcode_get_data (object);
 	gl_label_barcode_get_props (object,
-				    &id, &text_flag, &checksum_flag);
+				    &id, &text_flag, &checksum_flag, &format_digits);
 	color = gl_label_object_get_line_color (GL_LABEL_OBJECT(object));
 	gl_label_object_get_size (GL_LABEL_OBJECT(object), &w, &h);
 
@@ -1112,7 +1157,7 @@ draw_outline (PrintInfo *pi,
 
 	label_type = gl_template_get_first_label_type (pi->template);
 
-	gnome_print_setrgbcolor (pi->pc, 0.25, 0.25, 0.25);
+	gnome_print_setrgbcolor (pi->pc, 0.0, 0.0, 0.0);
 	gnome_print_setopacity (pi->pc, 1.0);
 	gnome_print_setlinewidth (pi->pc, 0.25);
 
@@ -1178,7 +1223,7 @@ clip_to_outline (PrintInfo *pi,
 	const glTemplateLabelType *label_type;
 	gdouble                    w, h, r;
 	gdouble                    r1;
-	gdouble                    waste;
+	gdouble                    waste, x_waste, y_waste;
 
 	gl_debug (DEBUG_PRINT, "START");
 
@@ -1189,28 +1234,31 @@ clip_to_outline (PrintInfo *pi,
 	case GL_TEMPLATE_SHAPE_RECT:
 		gl_label_get_size (label, &w, &h);
 		r = label_type->size.rect.r;
-		waste = label_type->waste;
+		x_waste = label_type->size.rect.x_waste;
+		y_waste = label_type->size.rect.y_waste;
 		if (r == 0.0) {
 			/* simple rectangle */
 			create_rectangle_path (pi->pc,
-					       -waste, -waste, w+2*waste, h+2*waste);
+					       -x_waste, -y_waste,
+					       w+2*x_waste, h+2*y_waste);
 		} else {
 			/* rectangle with rounded corners */
-			create_rounded_rectangle_path (pi->pc, -waste, -waste,
-						       w+2*waste, h+2*waste, r);
+			create_rounded_rectangle_path (pi->pc,
+						       -x_waste, -y_waste,
+						       w+2*x_waste, h+2*y_waste, r);
 		}
 		gnome_print_clip (pi->pc);
 		break;
 
 	case GL_TEMPLATE_SHAPE_ROUND:
 		r1 = label_type->size.round.r;
-		waste = label_type->waste;
+		waste = label_type->size.round.waste;
 		create_ellipse_path (pi->pc, r1, r1, r1+waste, r1+waste);
 		gnome_print_clip (pi->pc);
 		break;
 
 	case GL_TEMPLATE_SHAPE_CD:
-		waste = label_type->waste;
+		waste = label_type->size.cd.waste;
 		if ((label_type->size.cd.h == 0) && (label_type->size.cd.w == 0)) {
 			/* CD style, round label w/ concentric round hole */
 			r1 = label_type->size.cd.r1;
@@ -1262,7 +1310,7 @@ clip_punchouts (PrintInfo *pi,
 
 	case GL_TEMPLATE_SHAPE_CD:
 		gl_label_get_size (label, &w, &h);
-		waste = label_type->waste;
+		waste = label_type->size.cd.waste;
 		r2    = label_type->size.cd.r2;
 		create_ellipse_path (pi->pc, w/2, h/2, r2-waste, r2-waste);
 		gnome_print_setrgbcolor (pi->pc, 1.0, 1.0, 1.0);
