@@ -98,7 +98,7 @@ gl_view_barcode_get_type (void)
 	static GType type = 0;
 
 	if (!type) {
-		GTypeInfo info = {
+		static const GTypeInfo info = {
 			sizeof (glViewBarcodeClass),
 			NULL,
 			NULL,
@@ -108,6 +108,7 @@ gl_view_barcode_get_type (void)
 			sizeof (glViewBarcode),
 			0,
 			(GInstanceInitFunc) gl_view_barcode_instance_init,
+			NULL
 		};
 
 		type = g_type_register_static (GL_TYPE_VIEW_OBJECT,
@@ -261,6 +262,7 @@ update_object_from_editor_cb (glObjectEditor *editor,
 	gchar             *id;
 	gboolean           text_flag, cs_flag;
 	guint              color;
+	guint              format_digits;
 
 	gl_debug (DEBUG_VIEW, "START");
 
@@ -282,10 +284,10 @@ update_object_from_editor_cb (glObjectEditor *editor,
 	gl_label_barcode_set_data (GL_LABEL_BARCODE(object), text_node);
 	gl_text_node_free (&text_node);
 
-	gl_object_editor_get_bc_style (editor, &id, &text_flag, &cs_flag);
+	gl_object_editor_get_bc_style (editor, &id, &text_flag, &cs_flag, &format_digits);
 	color = gl_object_editor_get_bc_color (editor);
 	gl_label_barcode_set_props (GL_LABEL_BARCODE(object),
-				    id, text_flag, cs_flag);
+				    id, text_flag, cs_flag, format_digits);
 	gl_label_object_set_line_color (object, color);
 	g_free (id);
 
@@ -312,6 +314,7 @@ update_editor_from_object_cb (glLabelObject  *object,
 	gboolean           text_flag, cs_flag;
 	guint              color;
 	glMerge           *merge;
+	guint              format_digits;
 
 	gl_debug (DEBUG_VIEW, "START");
 
@@ -319,9 +322,9 @@ update_editor_from_object_cb (glLabelObject  *object,
 	gl_object_editor_set_size (editor, w, h);
 
 	gl_label_barcode_get_props (GL_LABEL_BARCODE(object),
-				    &id, &text_flag, &cs_flag);
+				    &id, &text_flag, &cs_flag, &format_digits);
 	color = gl_label_object_get_line_color (object);
-	gl_object_editor_set_bc_style (editor, id, text_flag, cs_flag);
+	gl_object_editor_set_bc_style (editor, id, text_flag, cs_flag, format_digits);
 	gl_object_editor_set_bc_color (editor, color);
 	g_free (id);
 
@@ -451,7 +454,8 @@ gl_view_barcode_create_event_handler (GnomeCanvas *canvas,
 			gl_label_barcode_set_props (GL_LABEL_BARCODE(object),
 						    "POSTNET",
 						    FALSE,
-						    TRUE);
+						    TRUE,
+						    0);
 			gl_label_object_set_line_color (GL_LABEL_OBJECT(object),
 						    gl_color_set_opacity (
 						      gl_view_get_default_line_color(view),
@@ -480,7 +484,8 @@ gl_view_barcode_create_event_handler (GnomeCanvas *canvas,
 			gl_label_barcode_set_props (GL_LABEL_BARCODE(object),
 						    "POSTNET",
 						    FALSE,
-						    TRUE);
+						    TRUE,
+						    0);
 			gl_label_object_set_line_color (GL_LABEL_OBJECT(object),
 							gl_view_get_default_line_color(view));
 			gl_view_unselect_all (view);
@@ -535,18 +540,19 @@ draw_barcode (glViewBarcode *view_barcode)
 	GnomeFont *font;
 	GnomeGlyphList *glyphlist;
 	gdouble y_offset;
+	guint format_digits;
 
 	gl_debug (DEBUG_VIEW, "START");
 
 	/* Query label object and properties */
 	object = gl_view_object_get_object (GL_VIEW_OBJECT(view_barcode));
 	gl_label_barcode_get_props (GL_LABEL_BARCODE(object),
-				    &id, &text_flag, &checksum_flag);
+				    &id, &text_flag, &checksum_flag, &format_digits);
 	color = gl_label_object_get_line_color (object);
 	gl_label_object_get_size (object, &w, &h);
 	text_node = gl_label_barcode_get_data(GL_LABEL_BARCODE(object));
 	if (text_node->field_flag) {
-		digits = gl_barcode_default_digits (id);
+		digits = gl_barcode_default_digits (id, format_digits);
 	} else {
 		digits = gl_text_node_expand (text_node, NULL);
 	}
@@ -584,6 +590,8 @@ draw_barcode (glViewBarcode *view_barcode)
 						"y", y_offset,
 						"glyphlist", glyphlist, NULL);
 
+		gnome_glyphlist_unref (glyphlist);
+
 		view_barcode->private->item_list =
 			g_list_prepend (view_barcode->private->item_list, item);
 	} else {
@@ -633,6 +641,8 @@ draw_barcode (glViewBarcode *view_barcode)
 							"glyphlist", glyphlist,
 							NULL);
 
+			gnome_glyphlist_unref (glyphlist);
+
 			view_barcode->private->item_list =
 				g_list_prepend (view_barcode->private->item_list, item);
 
